This page contains **code snippets** (lines starting with ``>>>``), which are
being :ref:`tested <tested_docs>` during our development workflow. The following
snippet initializes the :term:`demo project` used throughout this page.
